import { useCallback, useMemo } from 'react'
import { Token } from '@uniswap/sdk-core'
import { useFavouriteTokens, useToggleFavouriteToken } from 'state/user/hooks'
import { ButtonStar } from 'components/Button'
import useTheme from 'hooks/useTheme'
import styled from 'styled-components/macro'

export const StyledButtonStar = styled(ButtonStar)`
  z-index: 9;
`

type FavouriteTokenButtonParams = {
  tokenData: Token
}

export default function FavouriteTokenButton({ tokenData }: FavouriteTokenButtonParams) {
  const favouriteTokens = useFavouriteTokens()
  const theme = useTheme()

  const toggleFavouriteToken = useToggleFavouriteToken()

  const handleFavouriteToken = useCallback(
    (event) => {
      event.preventDefault()
      toggleFavouriteToken(tokenData)
    },
    [toggleFavouriteToken, tokenData]
  )

  const isFavouriteToken = useMemo(
    () => favouriteTokens.some((t: Token) => t.address === tokenData.address),
    [favouriteTokens, tokenData]
  )

  return (
    <StyledButtonStar
      stroke={theme.yellow2}
      fill={isFavouriteToken ? theme.yellow2 : undefined}
      onClick={handleFavouriteToken}
    />
  )
}
